/*
 * Copyright (C) 2006-2007 Andre Noll <maan@systemlinux.org>
 *
 *     This program is free software; you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation; either version 2 of the License, or
 *     (at your option) any later version.
 *
 *     This program is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with this program; if not, write to the Free Software
 *     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
 */

/** \file user_list.h exported functions from user_list.c */

#include "list.h"
#include "crypt.h"

/**
 * permission flags that can be set individually for any server command
 *
 * - AFS_READ: read-only command of the audio file selector
 * - AFS_WRITE: command changes state of the audio file selector
 * - VSS_READ: command reads information about the current audio stream
 * - VSS_WRITE: command changes the current audio stream
 */
enum {AFS_READ = 1, AFS_WRITE = 2, VSS_READ = 4, VSS_WRITE = 8};

/**
 * data needed to authenticate the user
 */
struct user {
	/** the position of this user in the list of users */
	struct list_head node;
	/** the username */
	char *name;
	/**  the public RSA key */
	RSA *rsa;
	/** the privileges that this user has */
	unsigned int perms;
};

void init_user_list(char *user_list_file);
struct user *lookup_user(const char *name);
